@@ -15,7 +15,7 @@
 #' @param handleWidth Width of the left and right sides in pixels.
 #' @param disabled Logical, display the toggle switch in disabled state?.
 #' @param inline Logical, display the toggle switch inline?
-#' @param width The width of the input : 'auto', 'fit', '100px', '75\%'.
+#' @param width The width of the input : 'auto', 'fit', '100px', '75%'.
 #'
 #' @return A switch control that can be added to a UI definition.
 #'
@@ -325,7 +325,8 @@ switchInput <- function(inputId,
 #'   shinyApp(ui = ui, server = server)
 #'
 #' }
-updateSwitchInput <- function(session, inputId,
+updateSwitchInput <- function(session = getDefaultReactiveDomain(),
+                              inputId,
                               value = NULL, label = NULL,
                               onLabel = NULL, offLabel = NULL,
                               onStatus = NULL, offStatus = NULL,
